@@ -141,7 +141,7 @@ class FileTransaction(transaction.TransactionElement):
             self._content = content
         else:
             if isinstance(content, list) or isinstance(content, tuple):
-                self._content = '\n'.join([common.toStr(i) for i in content])
+                self._content = u'\n'.join([common.toUStr(i) for i in content])
                 if content:
                     self._content += '\n'
             else:
