@@ -19,6 +19,8 @@ import dnf.logging
 import dnf.subject
 import dnf.yum.rpmtrans
 
+from dnf.cli.cli import Cli
+
 from . import packager
 
 
@@ -342,7 +344,14 @@ class MiniDNF():
             base.conf.installroot,
             varsdir=base.conf.varsdir,
         )
-        base.init_plugins(disabled_glob=self._disabledPlugins)
+
+        # dnf seems to behave differently depending on whether cli is passed
+        # or not (defaults to None). With None, filtering out disabled plugins
+        # does not work well. Not sure whether that's by design or a bug.
+        # See also: https://bugzilla.redhat.com/show_bug.cgi?id=1919803
+        cli = Cli(base)
+        base.init_plugins(disabled_glob=self._disabledPlugins, cli=cli)
+
         base.pre_configure_plugins()
         base.read_all_repos()
         base.configure_plugins()
@@ -416,14 +425,14 @@ class MiniDNF():
                     action=action,
                 )
             )
-            g = self._base.comps._group_by_id(group)
-            if g is None:
+            groups = [g for g in self._base.comps.groups if g.id == group]
+            if not groups:
                 raise dnf.exceptions.Error(
                     _('Group {group} cannot be resolved').format(
                         group=group,
                     )
                 )
-            call(g.id)
+            call(groups[0].id)
             return True
         except dnf.exceptions.Error as e:
             msg = _("Cannot queue group '{group}': {error}").format(
@@ -656,7 +665,19 @@ class MiniDNF():
                 base.transaction.install_set,
                 progress=self._MyDownloadProgress(self._sink),
             )
-            # TODO add package checking once dnf exports this in API
+            for po in base.transaction.install_set:
+                result, errmsg = base.package_signature_check(po)
+                if result == 0:
+                    pass
+                elif result == 1:
+                    def _askGPG(d):
+                        return self._sink.askForGPGKeyImport(
+                            d['userid'],
+                            d['hexkeyid'],
+                        )
+                    base.package_import_key(po, fullaskcb=_askGPG)
+                else:
+                    raise RuntimeError(errmsg)
 
             base.do_transaction(display=self._MyTransactionDisplay(self._sink))
         except Exception as e:
@@ -686,7 +707,7 @@ class MiniDNF():
             _('install'),
             lambda group: self._base.group_install(
                 group,
-                pkg_types=('default',),
+                pkg_types=('mandatory', 'default'),
             ),
             group,
             **kwargs
