@@ -219,8 +219,10 @@ class Plugin(plugin.PluginBase, dialog.DialogBaseImpl):
                 self.logger.error(_('Please specify value'))
             else:
                 accepted = True
-                self.environment[envkey] = value
 
+        self.environment[envkey] = value
+        if hidden:
+            self.environment[constants.CoreEnv.LOG_FILTER].append(value)
         return value
 
     def queryMultiString(self, name, note=None):
